@@ -142,6 +142,22 @@ Total number of served requests with status of 400-499.
 
 Total number of served requests with status of 500-599.
 
+=item C<http_status_404>
+
+Total number of served requests with status of 404.
+
+=item C<http_status_499>
+
+Total number of served requests with status of 499.
+
+=item C<http_status_500>
+
+Total number of served requests with status of 500.
+
+=item C<http_status_502>
+
+Total number of served requests with status of 502.
+
 =back
 
 
@@ -323,7 +339,7 @@ sub stats_zone {
 		/^http_status_([1-5])/ and do {
 			$out{'http_status_'. $1.'xx'} += $pub->{$_};
 			# particular statuses
-			/^http_status_(404|500)/ and do {
+			/^http_status_(404|500|502)/ and do {
 				$out{'http_status_'. $1} += $pub->{$_};
 			};
 			next;
